@@ -38,7 +38,8 @@ def compile_docker_image(Dockerfile, tag=None, no_cache=False):
     base = os.path.dirname(Dockerfile)
     if tag == None:
         tag = os.path.basename(base)
-    os.system(f"cd {base} && docker build {'--no-cache' if no_cache else ''} --tag {tag} .")
+    cmd = f"cd {base} && docker build {'--no-cache' if no_cache else ''} --tag {tag} ."
+    os.system(cmd)
     return tag
 
 
