@@ -39,10 +39,13 @@ def lload(flist, excl):
     s = rmimports(s, excl)  # remove import statements from helper class.
     return s
 
-def setup_grade_file_report(ReportClass, execute=False, obfuscate=False, minify=False, bzip=True, nonlatin=False, source_process_fun=None, with_coverage=True):
+def setup_grade_file_report(ReportClass, execute=False, obfuscate=False, minify=False, bzip=True, nonlatin=False, source_process_fun=None, with_coverage=True, verbose=True):
     print("Setting up answers...")
+    url = ReportClass.url
+    ReportClass.url = None
     report = ReportClass()
-    payload = report._setup_answers(with_coverage=with_coverage)
+    # report.url = None # We set the URL to none to skip the consistency checks with the remote source.
+    payload = report._setup_answers(with_coverage=with_coverage, verbose=verbose)
     payload['config'] = {}
     from unitgrade_private.hidden_gather_upload import gather_report_source_include
     sources = gather_report_source_include(report)
@@ -51,8 +54,7 @@ def setup_grade_file_report(ReportClass, execute=False, obfuscate=False, minify=
     payload['config']['blake2b_file_hashes'] = known_hashes
     time.sleep(0.1)
     print("Packing student files...")
-    # pack report into a binary blob thingy the students can run on their own.
-    # report = ReportClass()
+
     fn = inspect.getfile(ReportClass)
     with open(fn, 'r') as f:
         report1_source = f.read()
@@ -78,13 +80,13 @@ def setup_grade_file_report(ReportClass, execute=False, obfuscate=False, minify=
     from unitgrade import version
     from unitgrade import utils
     from unitgrade import runners
-    print(unitgrade.__file__)
+    # print(unitgrade.__file__)
     report1_source = lload([unitgrade.__file__, utils.__file__, runners.__file__, unitgrade.framework.__file__,
                             unitgrade.evaluate.__file__, hidden_gather_upload.__file__,
                             version.__file__], excl) + "\n" + report1_source
 
-    print(sys.getsizeof(picklestring))
-    print(len(picklestring))
+    # print(sys.getsizeof(picklestring))
+    # print(len(picklestring))
     s = jinja2.Environment().from_string(data).render({'Report1': ReportClass.__name__,
                                                        'source': repr(report1_source),
                                                        'payload': picklestring.hex(), #repr(picklestring),
@@ -134,4 +136,5 @@ def setup_grade_file_report(ReportClass, execute=False, obfuscate=False, minify=
         exec("import " + s)
 
     print("====== EXECUTION AND PACKING OF REPORT IS COMPLETE ======")
+    ReportClass.url = url
     return output
\ No newline at end of file
